"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.esbuildPluginAliasPath = exports.escapeNamespace = void 0;
const normalize_options_1 = require("./normalize-options");
const pluginName = 'esbuild:alias-path';
function escapeNamespace(keys) {
    return new RegExp(`^${keys
        .map((str) => str.replace(/[.*+?^${}()|[\]\\]/g, '\\$&'))
        .join('|')}$`);
}
exports.escapeNamespace = escapeNamespace;
const esbuildPluginAliasPath = (options = {}) => {
    const { alias, skip } = (0, normalize_options_1.normalizeOption)(options);
    if (skip) {
        return {
            name: pluginName,
            setup() {
                void 0;
            },
        };
    }
    const escapedNamespace = escapeNamespace(Object.keys(alias));
    return {
        name: pluginName,
        setup(build) {
            build.onResolve({ filter: escapedNamespace }, ({ path: fromPath }) => {
                const replacedPath = alias[fromPath];
                if (!replacedPath) {
                    return null;
                }
                return {
                    path: replacedPath,
                };
            });
        },
    };
};
exports.esbuildPluginAliasPath = esbuildPluginAliasPath;
